diff -Nur nginx-1.0.10-orig/src/http/modules/ngx_http_log_module.c nginx-1.0.10/src/http/modules/ngx_http_log_module.c
--- nginx-1.0.10-orig/src/http/modules/ngx_http_log_module.c	2011-11-01 14:24:50.000000000 +0100
+++ nginx-1.0.10/src/http/modules/ngx_http_log_module.c	2011-11-22 16:06:24.000000000 +0100
@@ -50,6 +50,7 @@
     ngx_http_log_script_t      *script;
     time_t                      disk_full_time;
     time_t                      error_log_time;
+    off_t                       size;
     ngx_http_log_fmt_t         *format;
 } ngx_http_log_t;
 
@@ -133,7 +134,7 @@
 
     { ngx_string("access_log"),
       NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_HTTP_LIF_CONF
-                        |NGX_HTTP_LMT_CONF|NGX_CONF_TAKE123,
+                        |NGX_HTTP_LMT_CONF|NGX_CONF_TAKE1234,
       ngx_http_log_set_log,
       NGX_HTTP_LOC_CONF_OFFSET,
       0,
@@ -234,6 +235,17 @@
     }
 
     log = lcf->logs->elts;
+
+	/*
+	 * if the sent data is to small, do not log it
+	 */
+    off_t  length;
+
+    length = r->connection->sent - r->header_size;
+    if (length < log->size) {
+        return NGX_OK;
+    }
+
     for (l = 0; l < lcf->logs->nelts; l++) {
 
         if (ngx_time() == log[l].disk_full_time) {
@@ -854,6 +866,7 @@
     ngx_http_log_loc_conf_t *llcf = conf;
 
     ssize_t                     buf;
+    off_t                       size;
     ngx_uint_t                  i, n;
     ngx_str_t                  *value, name;
     ngx_http_log_t             *log;
@@ -951,7 +964,7 @@
 
 buffer:
 
-    if (cf->args->nelts == 4) {
+    if (cf->args->nelts >= 4) {
         if (ngx_strncmp(value[3].data, "buffer=", 7) != 0) {
             ngx_conf_log_error(NGX_LOG_EMERG, cf, 0,
                                "invalid parameter \"%V\"", &value[3]);
@@ -991,6 +1004,27 @@
         log->file->last = log->file->buffer + buf;
     }
 
+    if (cf->args->nelts == 5) {
+        if (ngx_strncmp(value[4].data, "size=", 5) != 0) {
+            ngx_conf_log_error(NGX_LOG_EMERG, cf, 0,
+                               "invalid parameter \"%V\"", &value[4]);
+            return NGX_CONF_ERROR;
+        }
+
+        name.len = value[4].len - 5;
+        name.data = value[4].data + 5;
+
+        size = ngx_parse_offset(&name);
+
+        if (size == NGX_ERROR) {
+            ngx_conf_log_error(NGX_LOG_EMERG, cf, 0,
+                               "invalid parameter \"%V\"", &value[4]);
+            return NGX_CONF_ERROR;
+        }
+
+        log->size = size;
+    }
+
     return NGX_CONF_OK;
 }
 
